@@ -8,17 +8,13 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Any, Dict, Optional, Type, Union, cast
 
+import xrpl.models.requests  # bare import to get around circular dependency
 from xrpl.models.base_model import BaseModel
 from xrpl.models.exceptions import XRPLModelException
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
-def _method_to_class_name(method: str) -> str:
-    snaked = "".join([word.capitalize() for word in method.split("_")])
-    return snaked
-
-
 class RequestMethod(str, Enum):
     """Represents the different options for the ``method`` field in a request."""
 
@@ -27,6 +23,7 @@ class RequestMethod(str, Enum):
     ACCOUNT_CURRENCIES = "account_currencies"
     ACCOUNT_INFO = "account_info"
     ACCOUNT_LINES = "account_lines"
+    ACCOUNT_NFTS = "account_nfts"
     ACCOUNT_OBJECTS = "account_objects"
     ACCOUNT_OFFERS = "account_offers"
     ACCOUNT_TX = "account_tx"
@@ -58,6 +55,10 @@ class RequestMethod(str, Enum):
     LEDGER_DATA = "ledger_data"
     LEDGER_ENTRY = "ledger_entry"
 
+    # NFT methods
+    NFT_BUY_OFFERS = "nft_buy_offers"
+    NFT_SELL_OFFERS = "nft_sell_offers"
+
     # subscription methods
     SUBSCRIBE = "subscribe"
     UNSUBSCRIBE = "unsubscribe"
@@ -72,6 +73,10 @@ class RequestMethod(str, Enum):
     PING = "ping"
     RANDOM = "random"
 
+    # generic unknown/unsupported request
+    # (there is no XRPL analog, this model is specific to xrpl-py)
+    GENERIC_REQUEST = "zzgeneric_request"
+
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
@@ -112,8 +117,13 @@ class Request(BaseModel):
 
         if "method" in value:
             method = value["method"]
-            if _method_to_class_name(method) != cls.__name__ and not (
-                method == "submit" and cls.__name__ in ("SignAndSubmit", "SubmitOnly")
+            if (
+                cls.get_method(method).__name__ != cls.__name__
+                and not (
+                    method == "submit"
+                    and cls.__name__ in ("SignAndSubmit", "SubmitOnly")
+                )
+                and not cls.__name__ == "GenericRequest"
             ):
                 raise XRPLModelException(
                     f"Using wrong constructor: using {cls.__name__} constructor "
@@ -133,22 +143,23 @@ class Request(BaseModel):
             method: The String name of the Request object.
 
         Returns:
-            The request class with the given name.
-
-        Raises:
-            XRPLModelException: If `method` is not a valid Request method.
+            The request class with the given name. If the request doesn't exist, then
+            it will return a `GenericRequest`.
         """
-        import xrpl.models.requests as request_models
+        # special case for NoRippleCheck and NFT methods
+        if method == RequestMethod.NO_RIPPLE_CHECK:
+            return xrpl.models.requests.NoRippleCheck
+        if method == RequestMethod.ACCOUNT_NFTS:
+            return xrpl.models.requests.AccountNFTs
+        if method == RequestMethod.NFT_BUY_OFFERS:
+            return xrpl.models.requests.NFTBuyOffers
+        if method == RequestMethod.NFT_SELL_OFFERS:
+            return xrpl.models.requests.NFTSellOffers
 
-        request_methods: Dict[str, Type[Request]] = {}
-        for r in RequestMethod:
-            method_name = _method_to_class_name(r.name)
-            request_methods[r.value] = getattr(request_models, method_name)
-
-        if method in request_methods:
-            return request_methods[method]
-
-        raise XRPLModelException(f"{method} is not a valid Request method")
+        parsed_name = "".join([word.capitalize() for word in method.split("_")])
+        if parsed_name in xrpl.models.requests.__all__:
+            return cast(Type[Request], getattr(xrpl.models.requests, parsed_name))
+        return xrpl.models.requests.GenericRequest
 
     def to_dict(self: Request) -> Dict[str, Any]:
         """
@@ -158,5 +169,5 @@ class Request(BaseModel):
             The dictionary representation of a Request.
         """
         # we need to override this because method is using ``field``
-        # which will not include the value in the objects __dict__
+        # which will not include the value in the object's __dict__
         return {**super().to_dict(), "method": self.method.value}
