@@ -5,6 +5,7 @@ from xrpl.asyncio.transaction import (
 )
 from xrpl.transaction.ledger import get_transaction_from_hash
 from xrpl.transaction.main import (
+    autofill,
     safe_sign_and_autofill_transaction,
     safe_sign_and_submit_transaction,
     safe_sign_transaction,
@@ -13,6 +14,7 @@ from xrpl.transaction.main import (
 from xrpl.transaction.reliable_submission import send_reliable_submission
 
 __all__ = [
+    "autofill",
     "get_transaction_from_hash",
     "safe_sign_transaction",
     "safe_sign_and_autofill_transaction",
